==> haskell-http-client-tls-0.3.6.4-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client-tls
version:              0.3.6.4
visibility:           public
id:                   http-client-tls-0.3.6.4-478LbZ0ZOdOEz9u9D7DeCU
key:                  http-client-tls-0.3.6.4-478LbZ0ZOdOEz9u9D7DeCU
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:
    http-client backend using the connection package and tls library

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.

category:             Network
abi:                  6dc9254d2cf33c78fc0b3e19297dc723
exposed:              True
exposed-modules:      Network.HTTP.Client.TLS
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.4.8/http-client-tls-0.3.6.4
hs-libraries:         HShttp-client-tls-0.3.6.4-478LbZ0ZOdOEz9u9D7DeCU
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-Bc7QIDcajSYD5EyDIDukoT containers-0.6.7
    crypton-1.0.0-F2pWGT0NRMlASY0hjjaDVz
    crypton-connection-0.4.1-DO1WytxdwpxB5qNckEJFJq
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi exceptions-0.10.5
    http-client-0.7.18-K4RY5DI3fa89LS1a2A03GX
    http-types-0.12.4-1ct1dd8yFZbHBxvHAGckYw
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-9bVsfPqpsd7CxIY0XrmbxB
    network-uri-2.6.4.2-F1pCk9rgbkv7rdfQWWKihk text-2.0.2
    tls-1.9.0-4oIzZ571arEEUB2oaa7FYZ transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock

haddock-html:         /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-tls-0.3.6.4-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client-tls
version:              0.3.6.4
visibility:           public
id:                   http-client-tls-0.3.6.4-6wdDSE7a7MH1UuelJ2W96c
key:                  http-client-tls-0.3.6.4-6wdDSE7a7MH1UuelJ2W96c
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:
    http-client backend using the connection package and tls library

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.

category:             Network
abi:                  da2901d7b0c22072e4554f88d303ee51
exposed:              True
exposed-modules:      Network.HTTP.Client.TLS
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.4.8/http-client-tls-0.3.6.4
hs-libraries:         HShttp-client-tls-0.3.6.4-6wdDSE7a7MH1UuelJ2W96c
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-Bc7QIDcajSYD5EyDIDukoT containers-0.6.7
    crypton-1.0.0-F2pWGT0NRMlASY0hjjaDVz
    crypton-connection-0.4.1-DO1WytxdwpxB5qNckEJFJq
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi exceptions-0.10.5
    http-client-0.7.18-2ofV5QEO18r5DBx66M5AT0
    http-types-0.12.4-DxE0ilwtjMO1bR6EnKEYPH
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-9bVsfPqpsd7CxIY0XrmbxB
    network-uri-2.6.4.2-F1pCk9rgbkv7rdfQWWKihk text-2.0.2
    tls-1.9.0-4oIzZ571arEEUB2oaa7FYZ transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock

haddock-html:         /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
